"""
##################################################################################
#
# Bänger by Marcin Orlowski
# Because your `banner` deserves to be a `bänger`!
#
# @author    Marcin Orlowski <mail@marcinOrlowski.com>
# Copyright  ©2025 Marcin Orlowski <MarcinOrlowski.com>
# @link      https://github.com/MarcinOrlowski/banger
#
##################################################################################
"""

from .core.base import BaseFont

"""Blur effect font."""


class BlurFont(BaseFont):
    """Blur effect font.

    Blur effect font with gradient on the left side
    """

    _FONT_DATA = {
        "name": "blur",
        "height": 7,
        "description": "Blur effect font with gradient on the left side",
        "bottom_padding": 1,
        "supports_lowercase": False,
        "characters": {
            "default": {
                "lines": [
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                    "░▒▓█▓▒▓█▓▒▓█▓▒",
                ]
            },
            " ": {
                "lines": ["    ", "    ", "    ", "    ", "    ", "    ", "    "],
                "trim": False,
            },
            "!": {
                "lines": [
                    "░▒▓██████",
                    "░▒▓██████",
                    "░▒▓██████",
                    "░▒▓██████",
                    "░▒▓██████",
                    "         ",
                    "░▒▓██████",
                ]
            },
            ".": {"lines": ["  ", "  ", "  ", "  ", "  ", "  ", "▓█"]},
            "0": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "░▒▓██▓  █████",
                    "░▒▓██▓█ █████",
                    "░▒▓██▓  █████",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "1": {
                "lines": [
                    "  ░▒▓█████ ",
                    " ░▒▓██████ ",
                    "░▒▓███████ ",
                    "  ░▒▓█████ ",
                    "  ░▒▓█████ ",
                    "  ░▒▓█████ ",
                    "░▒▓█████████",
                ]
            },
            "2": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "░▒▓██▓    ███",
                    "   ░▒▓█████  ",
                    "  ░▒▓█████   ",
                    " ░▒▓█████    ",
                    "░▒▓██████████",
                ]
            },
            "3": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "     ░▒▓█████",
                    " ░▒▓████████ ",
                    "     ░▒▓█████",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "4": {
                "lines": [
                    "   ░▒▓██████▓",
                    "  ░▒▓███████▓",
                    " ░▒▓████████▓",
                    "░▒▓██▓▓█████▓",
                    "░▒▓██████████",
                    "   ░▒▓██████▓",
                    "   ░▒▓██████▓",
                ]
            },
            "5": {
                "lines": [
                    "░▒▓██████████",
                    "░▒▓██████████",
                    "░▒▓██▓       ",
                    "░▒▓█████████ ",
                    "        █████",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "6": {
                "lines": [
                    " ░▒▓███████ ",
                    "░▒▓█████████",
                    "░▒▓███▓     ",
                    "░▒▓████████ ",
                    "░▒▓███▓ ████",
                    "░▒▓█████████",
                    " ░▒▓███████ ",
                ]
            },
            "7": {
                "lines": [
                    "░▒▓██████████",
                    "░▒▓██████████",
                    "     ░▒▓████ ",
                    "    ░▒▓████  ",
                    "   ░▒▓████   ",
                    "  ░▒▓████    ",
                    " ░▒▓████     ",
                ]
            },
            "8": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "░▒▓██▓  █████",
                    " ░▒▓████████ ",
                    "░▒▓██▓  █████",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "9": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "░▒▓██▓  █████",
                    " ░▒▓█████████",
                    "        █████",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "?": {
                "lines": [
                    " ░▒▓█████████ ",
                    "░▒▓███████████",
                    "░▒▓██▓  ██████",
                    "  ░▒▓████████ ",
                    "  ░▒▓██████   ",
                    "              ",
                    "  ░▒▓██████   ",
                ]
            },
            "A": {
                "lines": [
                    "  ░▒▓██████▓▒ ",
                    " ░▒▓████████▓▒",
                    "░▒▓███▓   ███▓",
                    "░▒▓███▓   ███▓",
                    "░▒▓██████████▓",
                    "░▒▓███▓   ███▓",
                    "░▒▓███▓   ███▓",
                ]
            },
            "B": {
                "lines": [
                    "░▒▓████████▓  ",
                    "░▒▓███▓  ████▓",
                    "░▒▓███▓  ████▓",
                    "░▒▓████████▓  ",
                    "░▒▓███▓  ████▓",
                    "░▒▓███▓  ████▓",
                    "░▒▓████████▓  ",
                ]
            },
            "C": {
                "lines": [
                    " ░▒▓███████",
                    "░▒▓████████ ",
                    "░▒▓██▓      ",
                    "░▒▓██▓      ",
                    "░▒▓██▓      ",
                    "░▒▓████████ ",
                    " ░▒▓███████",
                ]
            },
            "D": {
                "lines": [
                    "░▒▓████████   ",
                    "░▒▓██▓   ████ ",
                    "░▒▓██▓     ███",
                    "░▒▓██▓     ███",
                    "░▒▓██▓     ███",
                    "░▒▓██▓    ███ ",
                    "░▒▓█████████  ",
                ]
            },
            "E": {
                "lines": [
                    "░▒▓███████████",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓█████████  ",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓███████████",
                ]
            },
            "F": {
                "lines": [
                    "░▒▓███████████",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓█████████  ",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                ]
            },
            "G": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓████████  ",
                    "░▒▓██▓       ",
                    "░▒▓██▓  █████",
                    "░▒▓██▓     ██",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "H": {
                "lines": [
                    "░▒▓██▓   ███▓",
                    "░▒▓██▓   ███▓",
                    "░▒▓██▓   ███▓",
                    "░▒▓█████████▓",
                    "░▒▓██▓   ███▓",
                    "░▒▓██▓   ███▓",
                    "░▒▓██▓   ███▓",
                ]
            },
            "I": {
                "lines": [
                    "░▒▓██████",
                    " ░▒▓████ ",
                    " ░▒▓████ ",
                    " ░▒▓████ ",
                    " ░▒▓████ ",
                    " ░▒▓████ ",
                    "░▒▓██████",
                ]
            },
            "J": {
                "lines": [
                    "     ░▒▓█████",
                    "     ░▒▓█████",
                    "     ░▒▓█████",
                    "     ░▒▓█████",
                    "     ░▒▓█████",
                    "░▒▓██▓  █████",
                    " ░▒▓████████ ",
                ]
            },
            "K": {
                "lines": [
                    "░▒▓██▓   ████",
                    "░▒▓██▓  ███▓ ",
                    "░▒▓██▓ ███▓  ",
                    "░▒▓██████▓   ",
                    "░▒▓██▓ ███▓  ",
                    "░▒▓██▓  ███▓ ",
                    "░▒▓██▓   ████",
                ]
            },
            "L": {
                "lines": [
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓██▓        ",
                    "░▒▓███████████",
                    "░▒▓███████████",
                ]
            },
            "M": {
                "lines": [
                    "░▒▓██▓    ▓███",
                    "░▒▓███▓   ████",
                    "░▒▓████▓ █████",
                    "░▒▓██▓████▓███",
                    "░▒▓██▓ █  ▓███",
                    "░▒▓██▓    ▓███",
                    "░▒▓██▓    ▓███",
                ]
            },
            "N": {
                "lines": [
                    "░▒▓██▓    ████",
                    "░▒▓███▓   ████",
                    "░▒▓████▓  ████",
                    "░▒▓██▓ ██ ████",
                    "░▒▓██▓  ██████",
                    "░▒▓██▓   █████",
                    "░▒▓██▓    ████",
                ]
            },
            "O": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "░▒▓██▓    ███",
                    "░▒▓██▓    ███",
                    "░▒▓██▓    ███",
                    "░▒▓██████████",
                    " ░▒▓████████ ",
                ]
            },
            "P": {
                "lines": [
                    "░▒▓████████ ",
                    "░▒▓█████████",
                    "░▒▓██▓   ███",
                    "░▒▓█████████",
                    "░▒▓████████ ",
                    "░▒▓██▓      ",
                    "░▒▓██▓        ",
                ]
            },
            "Q": {
                "lines": [
                    " ░▒▓████████ ",
                    "░▒▓██████████",
                    "░▒▓██▓    ███",
                    "░▒▓██▓    ███",
                    "░▒▓██▓ ██▓███",
                    "░▒▓██████████",
                    " ░▒▓█████████",
                ]
            },
            "R": {
                "lines": [
                    "░▒▓██████████ ",
                    "░▒▓███████████",
                    "░▒▓██▓   ████ ",
                    "░▒▓█████████  ",
                    "░▒▓██▓ ████   ",
                    "░▒▓██▓  █████ ",
                    "░▒▓██▓   █████",
                ]
            },
            "S": {
                "lines": [
                    " ░▒▓███████ ",
                    "░▒▓█████████",
                    "░▒▓██▓      ",
                    " ░▒▓███████ ",
                    "        ████",
                    "░▒▓█████████",
                    " ░▒▓███████ ",
                ]
            },
            "T": {
                "lines": [
                    "░▒▓███████████",
                    "░▒▓███████████",
                    "   ░▒▓█████   ",
                    "   ░▒▓█████   ",
                    "   ░▒▓█████   ",
                    "   ░▒▓█████   ",
                    "   ░▒▓█████   ",
                ]
            },
            "U": {
                "lines": [
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    "░▒▓██████████ ",
                    " ░▒▓████████  ",
                ]
            },
            "V": {
                "lines": [
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    " ░▒▓██▓ ████  ",
                    "  ░▒▓██████   ",
                    "   ░▒▓████    ",
                ]
            },
            "W": {
                "lines": [
                    "░▒▓██▓    █████",
                    "░▒▓██▓    █████",
                    "░▒▓██▓    █████",
                    "░▒▓██▓ █  █████",
                    "░▒▓██▓███ █████",
                    "░▒▓████▓ ██████",
                    "░▒▓███▓   █████",
                ]
            },
            "X": {
                "lines": [
                    "░▒▓██▓   █████",
                    " ░▒▓██▓ █████ ",
                    "  ░▒▓███████  ",
                    "   ░▒▓█████   ",
                    "  ░▒▓███████  ",
                    " ░▒▓██▓ █████ ",
                    "░▒▓██▓   █████",
                ]
            },
            "Y": {
                "lines": [
                    "░▒▓██▓   █████",
                    "░▒▓██▓   █████",
                    " ░▒▓██▓ █████ ",
                    "  ░▒▓███████  ",
                    "   ░▒▓█████   ",
                    "   ░▒▓█████   ",
                    "   ░▒▓█████   ",
                ]
            },
            "Z": {
                "lines": [
                    "░▒▓██████████",
                    "░▒▓██████████",
                    "     ░▒▓████ ",
                    "    ░▒▓████  ",
                    "   ░▒▓████   ",
                    " ░▒▓█████    ",
                    "░▒▓██████████",
                ]
            },
            ",": {"lines": ["  ", "  ", "  ", "  ", "  ", "▓█", "▓ "]},
        },
    }
