"""
##################################################################################
#
# Bänger by Marcin Orlowski
# Because your `banner` deserves to be a `bänger`!
#
# @author    Marcin Orlowski <mail@marcinOrlowski.com>
# Copyright  ©2025 Marcin Orlowski <MarcinOrlowski.com>
# @link      https://github.com/MarcinOrlowski/banger
#
##################################################################################
"""

from .core.base import BaseFont

"""Compact font with 5-line height."""


class SmallFont(BaseFont):
    """Compact font with 5-line height.

    Compact font with 5-line height for space-efficient display
    """

    _FONT_DATA = {
        "name": "small",
        "height": 5,
        "description": "Compact font with 5-line height for space-efficient display",
        "bottom_padding": 1,
        "characters": {
            "default": {
                "lines": [
                    "# # ",
                    " # #",
                    "# # ",
                    " # #",
                    "# # ",
                ]
            },
            " ": {"lines": ["   ", "   ", "   ", "   ", "   "], "trim": False},
            "!": {"lines": ["#", "#", "#", " ", "#"]},
            ".": {"lines": [" ", " ", " ", " ", "#"]},
            "0": {"lines": [" ## ", "#  #", "#  #", "#  #", " ## "]},
            "1": {"lines": [" # ", "## ", " # ", " # ", "###"]},
            "2": {"lines": ["### ", "   #", " ## ", "#   ", "####"]},
            "3": {"lines": ["### ", "   #", " ## ", "   #", "### "]},
            "4": {"lines": ["#  #", "#  #", "####", "   #", "   #"]},
            "5": {"lines": ["####", "#   ", "### ", "   #", "### "]},
            "6": {"lines": [" ## ", "#   ", "### ", "#  #", " ## "]},
            "7": {"lines": ["####", "   #", "  # ", " #  ", "#   "]},
            "8": {"lines": [" ## ", "#  #", " ## ", "#  #", " ## "]},
            "9": {"lines": [" ## ", "#  #", " ###", "   #", " ## "]},
            "?": {"lines": ["## ", "  #", " # ", "   ", " # "]},
            "A": {"lines": [" ## ", "#  #", "####", "#  #", "#  #"]},
            "B": {"lines": ["### ", "#  #", "### ", "#  #", "### "]},
            "C": {"lines": [" ###", "#   ", "#   ", "#   ", " ###"]},
            "D": {"lines": ["### ", "#  #", "#  #", "#  #", "### "]},
            "E": {"lines": ["####", "#   ", "### ", "#   ", "####"]},
            "F": {"lines": ["####", "#   ", "### ", "#   ", "#   "]},
            "G": {"lines": [" ###", "#   ", "# ##", "#  #", " ###"]},
            "H": {"lines": ["#  #", "#  #", "####", "#  #", "#  #"]},
            "I": {"lines": ["###", " # ", " # ", " # ", "###"]},
            "J": {"lines": ["   #", "   #", "   #", "#  #", " ## "]},
            "K": {"lines": ["#  #", "# # ", "##  ", "# # ", "#  #"]},
            "L": {"lines": ["#   ", "#   ", "#   ", "#   ", "####"]},
            "M": {"lines": ["#   #", "## ##", "# # #", "#   #", "#   #"]},
            "N": {"lines": ["#  #", "## #", "# ##", "#  #", "#  #"]},
            "O": {"lines": [" ## ", "#  #", "#  #", "#  #", " ## "]},
            "P": {"lines": ["### ", "#  #", "### ", "#   ", "#   "]},
            "Q": {"lines": [" ## ", "#  #", "#  #", "# ##", " ###"]},
            "R": {"lines": ["### ", "#  #", "### ", "# # ", "#  #"]},
            "S": {"lines": [" ###", "#   ", " ## ", "   #", "### "]},
            "T": {"lines": ["###", " # ", " # ", " # ", " # "]},
            "U": {"lines": ["#  #", "#  #", "#  #", "#  #", " ## "]},
            "V": {"lines": ["#  #", "#  #", "#  #", " ## ", " ## "]},
            "W": {"lines": ["#   #", "#   #", "# # #", "## ##", "#   #"]},
            "X": {"lines": ["#  #", " ## ", " ## ", " ## ", "#  #"]},
            "Y": {"lines": ["#  #", "#  #", " ## ", " #  ", " #  "]},
            "Z": {"lines": ["####", "  # ", " #  ", "#   ", "####"]},
            "a": {"lines": ["   ", "###", "# #", "###", "# #"]},
            "b": {"lines": ["#  ", "#  ", "###", "# #", "###"]},
            "c": {"lines": ["   ", "   ", "###", "#  ", "###"]},
            "d": {"lines": ["  #", "  #", "###", "# #", "###"]},
            "e": {"lines": ["   ", "   ", "## ", "###", "## "]},
            "f": {"lines": [" ##", " # ", "###", " # ", " # "]},
            "g": {"lines": ["   ", "###", "# #", "###", " ##"]},
            "h": {"lines": ["#  ", "#  ", "###", "# #", "# #"]},
            "i": {"lines": ["# ", "  ", "##", "# ", "##"]},
            "j": {"lines": [" #", "  ", " #", " #", "# "]},
            "k": {"lines": ["#  ", "#  ", "# #", "## ", "# #"]},
            "l": {"lines": ["#", "#", "#", "#", "#"]},
            "m": {"lines": ["     ", "     ", "## ##", "# # #", "#   #"]},
            "n": {"lines": ["   ", "   ", "###", "# #", "# #"]},
            "o": {"lines": ["   ", "   ", "### ", "# #", "### "]},
            "p": {"lines": ["   ", "###", "# #", "###", "#  "]},
            "q": {"lines": ["   ", "###", "# #", "###", "  #"]},
            "r": {"lines": ["   ", "   ", "# #", "## ", "#  "]},
            "s": {"lines": ["   ", "###", "#  ", " ##", "###"]},
            "t": {"lines": [" # ", " # ", "###", " # ", " ##"]},
            "u": {"lines": ["   ", "   ", "# #", "# #", "###"]},
            "v": {"lines": ["   ", "   ", "# #", "# #", " # "]},
            "w": {"lines": ["     ", "     ", "# # #", "# # #", " ### "]},
            "x": {"lines": ["   ", "   ", "# #", " # ", "# #"]},
            "y": {"lines": ["   ", "# #", "# #", "###", "  #"]},
            "z": {"lines": ["   ", "   ", "###", " # ", "###"]},
            ",": {"lines": [" ", " ", " ", "#", "#"]},
        },
    }
